/*++
Copyright (c) 2006 Microsoft Corporation

Module Name:

    inf_s_integer.cpp

Abstract:

    <abstract>

Author:

    Leonardo de Moura (leonardo) 2007-06-16.

Revision History:

--*/

#include "util/inf_s_integer.h"

inf_s_integer inf_s_integer::m_zero(0);
inf_s_integer inf_s_integer::m_one(1);
inf_s_integer inf_s_integer::m_minus_one(-1);

